@@ -156,7 +156,7 @@ class EnvConfig(dict):
 
         raise KeyError("not a valid configuration key", key)
 
-    def export_dict(self) -> Dict[str, str]:
+    def export_dict(self) -> Dict[str, Any]:
         """
         Exports a dictionary.
         """
