@@ -31,6 +31,6 @@ import warnings
 
 if os.environ.get('WENV_DEBUG', '0') == '1':
     from typeguard import typechecked
-    warnings.warn("running in debug mode with activated run-time type checks", RuntimeWarning)
+    warnings.warn("wenv running in debug mode with activated run-time type checks", RuntimeWarning)
 else:
     typechecked = lambda x: x
